==> jc-1.4.0.tar.gz: soot/shimple/toolkits/scalar/SEvaluator.h <==
// public class soot.shimple.toolkits.scalar.SEvaluator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e979d7dfbaa0ed47 soot_shimple_toolkits_scalar_SEvaluator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_shimple_toolkits_scalar_SEvaluator_H_
#define _JC_soot_shimple_toolkits_scalar_SEvaluator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Value$object;
struct _jc_soot_jimple_Constant$object;

// Typedefs
typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator$sub_refs	_jc_soot_shimple_toolkits_scalar_SEvaluator$sub_refs;
typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator$sub_nonrefs	_jc_soot_shimple_toolkits_scalar_SEvaluator$sub_nonrefs;
typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator$refs	_jc_soot_shimple_toolkits_scalar_SEvaluator$refs;
typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator$nonrefs	_jc_soot_shimple_toolkits_scalar_SEvaluator$nonrefs;
typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator$object	_jc_soot_shimple_toolkits_scalar_SEvaluator$object;

typedef const struct _jc_soot_shimple_toolkits_scalar_SEvaluator$vmethods	_jc_soot_shimple_toolkits_scalar_SEvaluator$vmethods;
typedef const struct _jc_soot_shimple_toolkits_scalar_SEvaluator$vtable	_jc_soot_shimple_toolkits_scalar_SEvaluator$vtable;
typedef const struct _jc_soot_shimple_toolkits_scalar_SEvaluator$vtype	_jc_soot_shimple_toolkits_scalar_SEvaluator$vtype;

// Constructors
extern void _jc_soot_shimple_toolkits_scalar_SEvaluator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SEvaluator$object *);

// Static methods
extern struct _jc_object *_jc_soot_shimple_toolkits_scalar_SEvaluator$method$getConstantValueOf$118cbcc06cd1a4e8(_jc_env *, struct _jc_object *);
extern struct _jc_soot_jimple_Constant$object *_jc_soot_shimple_toolkits_scalar_SEvaluator$method$getFuzzyConstantValueOf$d99f06566a2a23fe(_jc_env *, struct _jc_object *);
extern struct _jc_soot_jimple_Constant$object *_jc_soot_shimple_toolkits_scalar_SEvaluator$method$getFuzzyConstantValueOf$d1b1f942d15925e2(_jc_env *, struct _jc_object *, struct _jc_object *);
extern jboolean _jc_soot_shimple_toolkits_scalar_SEvaluator$method$isValueConstantValued$771abbdbca4351a0(_jc_env *, struct _jc_object *);

// Virtual methods structure
struct _jc_soot_shimple_toolkits_scalar_SEvaluator$vmethods {
};

// Vtable
struct _jc_soot_shimple_toolkits_scalar_SEvaluator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_shimple_toolkits_scalar_SEvaluator$vmethods	soot_shimple_toolkits_scalar_SEvaluator;
};

// Vtype
struct _jc_soot_shimple_toolkits_scalar_SEvaluator$vtype {
	_jc_type			type;
	_jc_soot_shimple_toolkits_scalar_SEvaluator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_shimple_toolkits_scalar_SEvaluator$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_shimple_toolkits_scalar_SEvaluator$refs {
    _jc_soot_shimple_toolkits_scalar_SEvaluator$sub_refs	soot_shimple_toolkits_scalar_SEvaluator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_shimple_toolkits_scalar_SEvaluator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_shimple_toolkits_scalar_SEvaluator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_shimple_toolkits_scalar_SEvaluator$sub_nonrefs	soot_shimple_toolkits_scalar_SEvaluator;
};

// Object instance structure
struct _jc_soot_shimple_toolkits_scalar_SEvaluator$object {
	_jc_soot_shimple_toolkits_scalar_SEvaluator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_shimple_toolkits_scalar_SEvaluator$vtype	*vtype;
	_jc_soot_shimple_toolkits_scalar_SEvaluator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_shimple_toolkits_scalar_SEvaluator$vtype _jc_soot_shimple_toolkits_scalar_SEvaluator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_shimple_toolkits_scalar_SEvaluator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_shimple_toolkits_scalar_SEvaluator$class_object;

#endif	/* _JC_soot_shimple_toolkits_scalar_SEvaluator_H_ */

==> jc-1.4.6.tar.gz: soot/shimple/toolkits/scalar/SEvaluator.h <==
// public class soot.shimple.toolkits.scalar.SEvaluator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e979d7dfbaa0ed47 soot_shimple_toolkits_scalar_SEvaluator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_shimple_toolkits_scalar_SEvaluator_H_
#define _JC_soot_shimple_toolkits_scalar_SEvaluator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Value$object;
struct _jc_soot_jimple_Constant$object;

// Typedefs
typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator$sub_refs	_jc_soot_shimple_toolkits_scalar_SEvaluator$sub_refs;
typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator$sub_nonrefs	_jc_soot_shimple_toolkits_scalar_SEvaluator$sub_nonrefs;
typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator$refs	_jc_soot_shimple_toolkits_scalar_SEvaluator$refs;
typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator$nonrefs	_jc_soot_shimple_toolkits_scalar_SEvaluator$nonrefs;
typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator$object	_jc_soot_shimple_toolkits_scalar_SEvaluator$object;

typedef const struct _jc_soot_shimple_toolkits_scalar_SEvaluator$vmethods	_jc_soot_shimple_toolkits_scalar_SEvaluator$vmethods;
typedef const struct _jc_soot_shimple_toolkits_scalar_SEvaluator$vtable	_jc_soot_shimple_toolkits_scalar_SEvaluator$vtable;
typedef const struct _jc_soot_shimple_toolkits_scalar_SEvaluator$vtype	_jc_soot_shimple_toolkits_scalar_SEvaluator$vtype;

// Constructors
extern void _jc_soot_shimple_toolkits_scalar_SEvaluator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SEvaluator$object *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_object *_jc_soot_shimple_toolkits_scalar_SEvaluator$method$getConstantValueOf$118cbcc06cd1a4e8(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_Constant$object *_jc_soot_shimple_toolkits_scalar_SEvaluator$method$getFuzzyConstantValueOf$d99f06566a2a23fe(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_Constant$object *_jc_soot_shimple_toolkits_scalar_SEvaluator$method$getFuzzyConstantValueOf$d1b1f942d15925e2(_jc_env *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_shimple_toolkits_scalar_SEvaluator$method$isValueConstantValued$771abbdbca4351a0(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_shimple_toolkits_scalar_SEvaluator$vmethods {
};

// Vtable
struct _jc_soot_shimple_toolkits_scalar_SEvaluator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_shimple_toolkits_scalar_SEvaluator$vmethods	soot_shimple_toolkits_scalar_SEvaluator;
};

// Vtype
struct _jc_soot_shimple_toolkits_scalar_SEvaluator$vtype {
	_jc_type			type;
	_jc_soot_shimple_toolkits_scalar_SEvaluator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_shimple_toolkits_scalar_SEvaluator$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_shimple_toolkits_scalar_SEvaluator$refs {
    _jc_soot_shimple_toolkits_scalar_SEvaluator$sub_refs	soot_shimple_toolkits_scalar_SEvaluator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_shimple_toolkits_scalar_SEvaluator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_shimple_toolkits_scalar_SEvaluator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_shimple_toolkits_scalar_SEvaluator$sub_nonrefs	soot_shimple_toolkits_scalar_SEvaluator;
};

// Object instance structure
struct _jc_soot_shimple_toolkits_scalar_SEvaluator$object {
	_jc_soot_shimple_toolkits_scalar_SEvaluator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_shimple_toolkits_scalar_SEvaluator$vtype	*vtype;
	_jc_soot_shimple_toolkits_scalar_SEvaluator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_shimple_toolkits_scalar_SEvaluator$vtype _jc_soot_shimple_toolkits_scalar_SEvaluator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_shimple_toolkits_scalar_SEvaluator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_shimple_toolkits_scalar_SEvaluator$class_object;

#endif	/* _JC_soot_shimple_toolkits_scalar_SEvaluator_H_ */
